keyboard.py
-----------

.. automodule:: blessed.keyboard
   :members:
   :undoc-members:
   :private-members:
   :special-members: __new__
.. autofunction:: _alternative_left_right
.. autodata:: DEFAULT_SEQUENCE_MIXIN
.. autodata:: CURSES_KEYCODE_OVERRIDE_MIXIN
.. autodata:: _CURSES_KEYCODE_ADDINS
